#include "coolscan.h"
#include <stdio.h>
#include <stdlib.h>

int fd;
struct hello {
	int how_often;
	int uv_sum;
	int v_sum;
	
};
void unvary_parameter(){
	/*set_film_type(MONO_POSITIVE);*/
	linear_gamma();
}
	
void vary_parameter(){
	/*	set_film_type(MONO_NEGATIVE); */
	tv_gamma();
}
main(){
	unsigned char vbuf[10000];
	unsigned char uvbuf[10000];
	int i,j,k,time,gtime;
	struct hello data[256];	
	for(i=0;i<256;i++){
		data[i].v_sum=0;
		data[i].uv_sum=0;
		data[i].how_often = 0;
	}
	find_coolscan();
	specify_color_balance(1);
	set_film_type(MONO_POSITIVE);
	stage_move_to(-1);
	agof();
	avon();
	linear_gamma();
	for(time = 25; time <=100;time += 11){
	  	exp_time(time);	
	  for(gtime = 25;gtime<=100;gtime+=8){
	  register_color_balance_positive(1,gtime,gtime,gtime);
	  register_color_balance_negative(1,gtime,gtime,gtime);
	  register_color_balance_positive(1,gtime,gtime,gtime);

	    for(k=0;k<1;k++){
		unvary_parameter();
		read_line(800+20*time+5*gtime ,0,1,MAX_Y,uvbuf);
		vary_parameter();
		read_line(800+20*time+5*gtime,0,1,MAX_Y,vbuf);
		for(i=500;i<2000;i++){
			j = uvbuf[i];
			data[j].v_sum += vbuf[i];
			data[j].how_often++;
		}
	    } 
         }
	}
	for(i=0;i<256;i++){
		if(data[i].how_often > 1){
			printf("%d %d\n",i,data[i].v_sum /data[i].how_often);
		}
	}
	
}
